# $Id: systray.tcl,v 1.6 2005/11/20 01:09:37 aleksey Exp $

# Freedesktop systray icon support.
# Requires Tray package
# (ftp://ftp.atmsk.ru/pub/tkabber/tksystray.tar.gz)

##########################################################################

if {![cequal $::interface tk]} return

if {[catch { package require Tray }]} return

##########################################################################

namespace eval systray {
    variable s2p
    foreach {k v} [list available   available      \
                        away        available-away \
                        chat        available-chat \
                        dnd         available-dnd  \
                        xa          available-xa   \
                        unavailable unavailable    \
                        invisible   invisible      \
			blank       blank          \
			message1    message-server \
			message2    message        \
			message3    message-personal] {
        set s2p($k) [pixmap docking ${v}.gif]
    }
  
    variable options

    custom::defvar options(enable) 1 \
	[::msgcat::mc "Enable freedesktop systray icon."] \
	-group Systray -type boolean \
	-command [namespace code enable_disable]
}

##########################################################################

proc systray::enable_disable {args} {
    variable options

    set icon .si

    if {$options(enable) && ![winfo exists $icon]} {
	ifacetk::systray::create $icon \
	    -createcommand [namespace code create] \
	    -configurecommand [namespace code configure] \
	    -destroycommand [namespace code destroy]
    } elseif {!$options(enable) && [winfo exists $icon]} {
	ifacetk::systray::destroy $icon
    }
}

hook::add finload_hook [namespace current]::systray::enable_disable

##########################################################################

proc systray::create {icon} {
    variable s2p

    newti $icon -pixmap $s2p(unavailable)

    set m [ifacetk::systray::popupmenu $icon.menu]

    bind $icon <ButtonRelease-1> ifacetk::systray::toggle_state
    bind $icon <ButtonRelease-3> [list tk_popup $m %X %Y]

    bind $icon <Any-Enter>  [list ifacetk::systray::wrap_balloon $icon enter  %X %Y]
    bind $icon <Any-Motion> [list ifacetk::systray::wrap_balloon $icon motion %X %Y]
    bind $icon <Any-Leave>  [list ifacetk::systray::wrap_balloon $icon leave  %X %Y]
}

##########################################################################

proc systray::configure {icon status} {
    variable s2p

    configureti $icon -pixmap $s2p($status)
}

##########################################################################

proc systray::destroy {icon} {
    if {![cequal $icon ""] && [winfo exists $icon]} {
	removeti $icon
	::destroy $icon
    }
}

##########################################################################

